@@ -16,30 +16,8 @@
  */
 
 #pragma once
-#include <glib.h>
 #include <stdlib.h>
-
-#define NETPLAN_PUBLIC __attribute__ ((visibility("default")))
-#define NETPLAN_INTERNAL __attribute__ ((visibility("default")))
-#define NETPLAN_ABI __attribute__ ((visibility("default")))
-
-#define NETPLAN_DEPRECATED __attribute__ ((deprecated))
-
-#define NETPLAN_BUFFER_TOO_SMALL -2
-
-/**
- * Represent a configuration stanza
- */
-typedef struct netplan_net_definition NetplanNetDefinition;
-typedef struct netplan_state NetplanState;
-
-typedef enum {
-    NETPLAN_BACKEND_NONE,
-    NETPLAN_BACKEND_NETWORKD,
-    NETPLAN_BACKEND_NM,
-    NETPLAN_BACKEND_OVS,
-    NETPLAN_BACKEND_MAX_,
-} NetplanBackend;
+#include "types.h"
 
 NETPLAN_PUBLIC NetplanState*
 netplan_state_new();
@@ -59,6 +37,24 @@ netplan_state_get_netdefs_size(const NetplanState* np_state);
 NETPLAN_PUBLIC NetplanNetDefinition*
 netplan_state_get_netdef(const NetplanState* np_state, const char* id);
 
+NETPLAN_PUBLIC gboolean
+netplan_state_finish_nm_write(
+        const NetplanState* np_state,
+        const char* rootdir,
+        NetplanError** error);
+
+NETPLAN_PUBLIC gboolean
+netplan_state_finish_ovs_write(
+        const NetplanState* np_state,
+        const char* rootdir,
+        NetplanError** error);
+
+NETPLAN_PUBLIC gboolean
+netplan_state_finish_sriov_write(
+        const NetplanState* np_state,
+        const char* rootdir,
+        NetplanError** error);
+
 /* Write the selected yaml file. All definitions that originate from this file,
  * as well as those without any given origin, are written to it.
  */
@@ -67,7 +63,7 @@ netplan_state_write_yaml_file(
         const NetplanState* np_state,
         const char* filename,
         const char* rootdir,
-        GError** error);
+        NetplanError** error);
 
 /* Update all the YAML files that were used to create this state.
  * The definitions without clear origin are written to @default_filename.
@@ -77,7 +73,7 @@ netplan_state_update_yaml_hierarchy(
         const NetplanState* np_state,
         const char* default_filename,
         const char* rootdir,
-        GError** error);
+        NetplanError** error);
 
 /* Dump the whole yaml configuration into the given file, regardless of the origin
  * of each definition.
@@ -86,18 +82,51 @@ NETPLAN_PUBLIC gboolean
 netplan_state_dump_yaml(
         const NetplanState* np_state,
         int output_fd,
-        GError** error);
+        NetplanError** error);
 
 NETPLAN_PUBLIC gboolean
 netplan_netdef_write_yaml(
         const NetplanState* np_state,
         const NetplanNetDefinition* netdef,
         const char* rootdir,
-        GError** error);
+        NetplanError** error);
 
 NETPLAN_PUBLIC ssize_t
 netplan_netdef_get_filepath(const NetplanNetDefinition* netdef, char* out_buffer, size_t out_buffer_size);
 
+NETPLAN_PUBLIC NetplanBackend
+netplan_netdef_get_backend(const NetplanNetDefinition* netdef);
+
+NETPLAN_PUBLIC NetplanDefType
+netplan_netdef_get_type(const NetplanNetDefinition* netdef);
+
+NETPLAN_PUBLIC ssize_t
+netplan_netdef_get_id(const NetplanNetDefinition* netdef, char* out_buffer, size_t out_buffer_size);
+
+NETPLAN_PUBLIC NetplanNetDefinition*
+netplan_netdef_get_bridge_link(const NetplanNetDefinition* netdef);
+
+NETPLAN_PUBLIC NetplanNetDefinition*
+netplan_netdef_get_bond_link(const NetplanNetDefinition* netdef);
+
+NETPLAN_PUBLIC NetplanNetDefinition*
+netplan_netdef_get_peer_link(const NetplanNetDefinition* netdef);
+
+NETPLAN_PUBLIC NetplanNetDefinition*
+netplan_netdef_get_vlan_link(const NetplanNetDefinition* netdef);
+
+NETPLAN_PUBLIC NetplanNetDefinition*
+netplan_netdef_get_sriov_link(const NetplanNetDefinition* netdef);
+
+NETPLAN_PUBLIC ssize_t
+netplan_netdef_get_set_name(const NetplanNetDefinition* netdef, char* out_buffer, size_t out_buffer_size);
+
+NETPLAN_PUBLIC gboolean
+netplan_netdef_has_match(const NetplanNetDefinition* netdef);
+
+NETPLAN_PUBLIC gboolean
+netplan_netdef_match_interface(const NetplanNetDefinition* netdef, const char* name, const char* mac, const char* driver_name);
+
 /********** Old API below this ***********/
 
 NETPLAN_DEPRECATED NETPLAN_PUBLIC const char *
