@@ -145,10 +145,8 @@ class Interface():
     def query_nm_ssid(self, con_name: str) -> str:
         ssid: str = None
         try:
-            ssid = subprocess.check_output(['nmcli', '--get-values',
-                                            '802-11-wireless.ssid', 'con',
-                                            'show', 'id', con_name],
-                                           universal_newlines=True)
+            ssid = utils.nmcli_out(['--get-values', '802-11-wireless.ssid',
+                                    'con', 'show', 'id', con_name])
             return ssid.strip()
         except Exception as e:
             logging.warning('Cannot query NetworkManager SSID for {}: {}'.format(
@@ -158,8 +156,7 @@ class Interface():
     def query_networkctl(self, ifname: str) -> str:
         output: str = None
         try:
-            output = subprocess.check_output(['networkctl', 'status', ifname],
-                                             universal_newlines=True)
+            output = subprocess.check_output(['networkctl', 'status', '--', ifname], text=True)
         except Exception as e:
             logging.warning('Cannot query networkctl for {}: {}'.format(
                 ifname, str(e)))
@@ -360,7 +357,7 @@ class NetplanStatus(utils.NetplanCommand):
         data: JSON = None
         try:
             output: str = subprocess.check_output(['ip', '-d', '-j', 'addr'],
-                                                  universal_newlines=True)
+                                                  text=True)
             data = self.process_generic(output)
         except Exception as e:
             logging.critical('Cannot query iproute2 interface data: {}'.format(str(e)))
@@ -373,7 +370,7 @@ class NetplanStatus(utils.NetplanCommand):
         data: JSON = None
         try:
             output: str = subprocess.check_output(['networkctl', '--json=short'],
-                                                  universal_newlines=True)
+                                                  text=True)
             data = self.process_networkd(output)
         except Exception as e:
             logging.critical('Cannot query networkd interface data: {}'.format(str(e)))
@@ -398,10 +395,9 @@ class NetplanStatus(utils.NetplanCommand):
     def query_nm(self) -> JSON:
         data: JSON = None
         try:
-            output: str = subprocess.check_output(['nmcli', '-t', '-f',
-                                                   'DEVICE,NAME,UUID,FILENAME,TYPE,AUTOCONNECT',
-                                                   'con', 'show'],
-                                                  universal_newlines=True)
+            output: str = utils.nmcli_out(['-t', '-f',
+                                           'DEVICE,NAME,UUID,FILENAME,TYPE,AUTOCONNECT',
+                                           'con', 'show'])
             data = self.process_nm(output)
         except Exception as e:
             logging.debug('Cannot query NetworkManager interface data: {}'.format(str(e)))
@@ -412,10 +408,10 @@ class NetplanStatus(utils.NetplanCommand):
         data6 = None
         try:
             output4: str = subprocess.check_output(['ip', '-d', '-j', 'route'],
-                                                   universal_newlines=True)
+                                                   text=True)
             data4: JSON = self.process_generic(output4)
             output6: str = subprocess.check_output(['ip', '-d', '-j', '-6', 'route'],
-                                                   universal_newlines=True)
+                                                   text=True)
             data6: JSON = self.process_generic(output6)
         except Exception as e:
             logging.debug('Cannot query iproute2 route data: {}'.format(str(e)))
