@@ -22,7 +22,7 @@
  */
 
 #include "netplan.h"
-#include "types.h"
+#include "types-internal.h"
 #include "util-internal.h"
 #include "parse-nm.h"
 #include "parse-globals.h"
@@ -129,7 +129,7 @@ write_netplan_conf_full(const char* file_hint, const char* rootdir)
         !netplan_state_get_netdefs_size(&global_state))
         return;
     path = g_build_path(G_DIR_SEPARATOR_S, rootdir ?: G_DIR_SEPARATOR_S, "etc", "netplan", file_hint, NULL);
-    int fd = open(path, O_WRONLY | O_CREAT | O_TRUNC, 0640);
+    int fd = open(path, O_WRONLY | O_CREAT | O_TRUNC, 0600);
     netplan_state_dump_yaml(&global_state, fd, NULL);
     close(fd);
 }
@@ -229,4 +229,38 @@ netplan_netdef_get_filename(const NetplanNetDefinition* netdef)
     g_assert(netdef);
     return netdef->filepath;
 }
+
+/*
+ * Deprecated, use _netplan_netdef_get_embedded_switch_mode instead
+ */
+NETPLAN_DEPRECATED NETPLAN_INTERNAL const char*
+netplan_netdef_get_embedded_switch_mode(const NetplanNetDefinition* netdef)
+{
+    g_assert(netdef);
+    return netdef->embedded_switch_mode;
+}
+
+/**
+ * Extract the netplan netdef ID from a NetworkManager connection profile (keyfile),
+ * generated by netplan. Used by the NetworkManager YAML backend.
+ *
+ * Note: Use netplan_get_id_from_nm_filepath instead.
+ */
+gchar*
+netplan_get_id_from_nm_filename(const char* filename, const char* ssid)
+{
+    size_t out_buf_size = 0;
+    ssize_t ret = 0;
+    g_autofree char* out_buffer = NULL;
+
+    out_buf_size = strlen(filename);
+    out_buffer = calloc(out_buf_size, 1);
+
+    ret = netplan_get_id_from_nm_filepath(filename, ssid, out_buffer, out_buf_size);
+
+    if (ret <= 0)
+        return NULL;
+
+    return g_strndup(out_buffer, ret);
+}
 // LCOV_EXCL_STOP
