@@ -47,6 +47,7 @@ netplan_def_type_to_str[NETPLAN_DEF_TYPE_MAX_] = {
     [NETPLAN_DEF_TYPE_BRIDGE] = "bridges",
     [NETPLAN_DEF_TYPE_BOND] = "bonds",
     [NETPLAN_DEF_TYPE_VLAN] = "vlans",
+    [NETPLAN_DEF_TYPE_VRF] = "vrfs",
     [NETPLAN_DEF_TYPE_TUNNEL] = "tunnels",
     [NETPLAN_DEF_TYPE_PORT] = "_ovs-ports",
     [NETPLAN_DEF_TYPE_NM] = "nm-devices",
@@ -80,6 +81,7 @@ netplan_tunnel_mode_to_str[NETPLAN_TUNNEL_MODE_MAX_] = {
     [NETPLAN_TUNNEL_MODE_IPIP6] = "ipip6",
     [NETPLAN_TUNNEL_MODE_IP6GRE] = "ip6gre",
     [NETPLAN_TUNNEL_MODE_VTI6] = "vti6",
+    [NETPLAN_TUNNEL_MODE_VXLAN] = "vxlan",
     [NETPLAN_TUNNEL_MODE_GRETAP] = "gretap",
     [NETPLAN_TUNNEL_MODE_IP6GRETAP] = "ip6gretap",
     [NETPLAN_TUNNEL_MODE_WIREGUARD] = "wireguard",
@@ -92,9 +94,24 @@ netplan_addr_gen_mode_to_str[NETPLAN_ADDRGEN_MAX] = {
     [NETPLAN_ADDRGEN_STABLEPRIVACY] = "stable-privacy"
 };
 
+static const char* const
+netplan_infiniband_mode_to_str[NETPLAN_IB_MODE_MAX_] = {
+    [NETPLAN_IB_MODE_KERNEL] = NULL,
+    [NETPLAN_IB_MODE_DATAGRAM] = "datagram",
+    [NETPLAN_IB_MODE_CONNECTED] = "connected"
+};
+
 #define NAME_FUNCTION(_radical, _type) const char *netplan_ ## _radical ## _name( _type val) \
 { \
-    return (val < sizeof( netplan_ ## _radical ## _to_str )) ?  netplan_ ## _radical ## _to_str [val] : NULL; \
+    return (val < sizeof(netplan_ ## _radical ## _to_str) / sizeof(char *)) ?  netplan_ ## _radical ## _to_str [val] : NULL; \
+}
+
+/* @num_flags needs to account for the 0x0 value (index 0), which doesn't
+ * represent any flag, but still exists. So subtract 1 from the array length. */
+#define NAME_FUNCTION_FLAGS(_radical) const char *netplan_ ## _radical ## _name( NetplanFlags val) \
+{ \
+    size_t num_flags = sizeof(netplan_ ## _radical ## _to_str) / sizeof(char *) - 1; \
+    return (val <= 1 << (num_flags - 1)) ?  netplan_ ## _radical ## _to_str [__builtin_ffs(val)] : NULL; \
 }
 
 NAME_FUNCTION(backend, NetplanBackend);
@@ -104,6 +121,10 @@ NAME_FUNCTION(auth_eap_method, NetplanAuthEAPMethod);
 NAME_FUNCTION(tunnel_mode, NetplanTunnelMode);
 NAME_FUNCTION(addr_gen_mode, NetplanAddrGenMode);
 NAME_FUNCTION(wifi_mode, NetplanWifiMode);
+NAME_FUNCTION(infiniband_mode, NetplanInfinibandMode);
+NAME_FUNCTION_FLAGS(vxlan_notification);
+NAME_FUNCTION_FLAGS(vxlan_checksum);
+NAME_FUNCTION_FLAGS(vxlan_extension);
 
 #define ENUM_FUNCTION(_radical, _type) _type netplan_ ## _radical ## _from_name(const char* val) \
 { \
