@@ -94,8 +94,8 @@ type_str(const NetplanNetDefinition* def)
             return "ip-tunnel";
         case NETPLAN_DEF_TYPE_NM:
             /* needs to be overriden by passthrough "connection.type" setting */
-            g_assert(def->backend_settings.nm.passthrough);
-            GData *passthrough = def->backend_settings.nm.passthrough;
+            g_assert(def->backend_settings.passthrough);
+            GData *passthrough = def->backend_settings.passthrough;
             return g_datalist_get_data(&passthrough, "connection.type");
         // LCOV_EXCL_START
         default:
@@ -330,7 +330,6 @@ write_bridge_params(const NetplanNetDefinition* def, GKeyFile *kf)
 static gboolean
 write_wireguard_params(const NetplanNetDefinition* def, GKeyFile *kf, GError** error)
 {
-    gchar* tmp_group = NULL;
     g_assert(def->tunnel.private_key);
 
     /* The key was already validated via validate_tunnel_grammar(), but we need
@@ -351,7 +350,7 @@ write_wireguard_params(const NetplanNetDefinition* def, GKeyFile *kf, GError** e
     for (guint i = 0; i < def->wireguard_peers->len; i++) {
         NetplanWireguardPeer *peer = g_array_index (def->wireguard_peers, NetplanWireguardPeer*, i);
         g_assert(peer->public_key);
-        tmp_group = g_strdup_printf("wireguard-peer.%s", peer->public_key);
+        g_autofree gchar* tmp_group = g_strdup_printf("wireguard-peer.%s", peer->public_key);
 
         if (peer->keepalive)
             g_key_file_set_integer(kf, tmp_group, "persistent-keepalive", peer->keepalive);
@@ -377,7 +376,6 @@ write_wireguard_params(const NetplanNetDefinition* def, GKeyFile *kf, GError** e
                 list[j] = g_array_index(peer->allowed_ips, char*, j);
             g_key_file_set_string_list(kf, tmp_group, "allowed-ips", list, peer->allowed_ips->len);
         }
-        g_free(tmp_group);
     }
     return TRUE;
 }
@@ -517,7 +515,7 @@ write_vxlan_parameters(const NetplanNetDefinition* def, GKeyFile* kf)
 
 /**
  * Special handling for passthrough mode: read key-value pairs from
- * "backend_settings.nm.passthrough" and inject them into the keyfile as-is.
+ * "backend_settings.passthrough" and inject them into the keyfile as-is.
  */
 static void
 write_fallback_key_value(GQuark key_id, gpointer value, gpointer user_data)
@@ -600,10 +598,10 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
     }
 
     kf = g_key_file_new();
-    if (ap && ap->backend_settings.nm.name)
-        g_key_file_set_string(kf, "connection", "id", ap->backend_settings.nm.name);
-    else if (def->backend_settings.nm.name)
-        g_key_file_set_string(kf, "connection", "id", def->backend_settings.nm.name);
+    if (ap && ap->backend_settings.name)
+        g_key_file_set_string(kf, "connection", "id", ap->backend_settings.name);
+    else if (def->backend_settings.name)
+        g_key_file_set_string(kf, "connection", "id", def->backend_settings.name);
     else {
         /* Auto-generate a name for the connection profile, if not specified */
         if (ap)
@@ -617,10 +615,10 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
     if (nm_type && def->type != NETPLAN_DEF_TYPE_NM)
         g_key_file_set_string(kf, "connection", "type", nm_type);
 
-    if (ap && ap->backend_settings.nm.uuid)
-        g_key_file_set_string(kf, "connection", "uuid", ap->backend_settings.nm.uuid);
-    else if (def->backend_settings.nm.uuid)
-        g_key_file_set_string(kf, "connection", "uuid", def->backend_settings.nm.uuid);
+    if (ap && ap->backend_settings.uuid)
+        g_key_file_set_string(kf, "connection", "uuid", ap->backend_settings.uuid);
+    else if (def->backend_settings.uuid)
+        g_key_file_set_string(kf, "connection", "uuid", def->backend_settings.uuid);
     /* VLAN/VXLAN devices refer to us as their parent; if our ID is not a name
      * but we have matches, parent= must be the connection UUID, so put it into
      * the connection */
@@ -667,8 +665,8 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
             write_bridge_params(def, kf);
         if (def->type == NETPLAN_DEF_TYPE_VRF) {
             g_key_file_set_uint64(kf, "vrf", "table", def->vrf_table);
-            write_routes(def, kf, AF_INET, error);
-            write_routes(def, kf, AF_INET6, error);
+            if (!write_routes(def, kf, AF_INET, error) || !write_routes(def, kf, AF_INET6, error))
+                return FALSE;
         }
     }
     if (def->type == NETPLAN_DEF_TYPE_MODEM) {
@@ -875,11 +873,11 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
     else
         g_key_file_set_string(kf, "ipv6", "method", "ignore");
 
-    if (def->backend_settings.nm.passthrough) {
+    if (def->backend_settings.passthrough) {
         g_debug("NetworkManager: using keyfile passthrough mode");
         /* Write all key-value pairs from the hashtable into the keyfile,
          * potentially overriding existing values, if not fully supported. */
-        g_datalist_foreach((GData**)&def->backend_settings.nm.passthrough, write_fallback_key_value, kf);
+        g_datalist_foreach((GData**)&def->backend_settings.passthrough, write_fallback_key_value, kf);
     }
 
     if (ap) {
@@ -909,14 +907,14 @@ write_nm_conf_access_point(const NetplanNetDefinition* def, const char* rootdir,
         if (ap->has_auth) {
             write_wifi_auth_parameters(&ap->auth, kf);
         }
-        if (ap->backend_settings.nm.passthrough) {
+        if (ap->backend_settings.passthrough) {
             g_debug("NetworkManager: using AP keyfile passthrough mode");
             /* Write all key-value pairs from the hashtable into the keyfile,
              * potentially overriding existing values, if not fully supported.
              * AP passthrough values have higher priority than ND passthrough,
              * because they are more specific and bound to the current SSID's
              * NM connection profile. */
-            g_datalist_foreach((GData**)&ap->backend_settings.nm.passthrough, write_fallback_key_value, kf);
+            g_datalist_foreach((GData**)&ap->backend_settings.passthrough, write_fallback_key_value, kf);
         }
     } else {
         /* TODO: make use of netplan_netdef_get_output_filename() */
