@@ -352,15 +352,29 @@ parse_dot1x_auth(GKeyFile* kf, NetplanAuthenticationSettings* auth)
     g_assert(auth);
     g_autofree gchar* method = g_key_file_get_string(kf, "802-1x", "eap", NULL);
 
-    if (method && g_strcmp0(method, "tls") == 0) {
-        auth->eap_method = NETPLAN_AUTH_EAP_TLS;
-        _kf_clear_key(kf, "802-1x", "eap");
-    } else if (method && g_strcmp0(method, "peap") == 0) {
-        auth->eap_method = NETPLAN_AUTH_EAP_PEAP;
-        _kf_clear_key(kf, "802-1x", "eap");
-    } else if (method && g_strcmp0(method, "ttls") == 0) {
-        auth->eap_method = NETPLAN_AUTH_EAP_TTLS;
-        _kf_clear_key(kf, "802-1x", "eap");
+    if (method && g_strcmp0(method, "") != 0) {
+        gchar** split = g_strsplit(method, ";", 2);
+        gchar* first_method = split[0];
+
+        if (g_strcmp0(first_method, "tls") == 0) {
+            auth->eap_method = NETPLAN_AUTH_EAP_TLS;
+        } else if (g_strcmp0(first_method, "peap") == 0) {
+            auth->eap_method = NETPLAN_AUTH_EAP_PEAP;
+        } else if (g_strcmp0(first_method, "ttls") == 0) {
+            auth->eap_method = NETPLAN_AUTH_EAP_TTLS;
+        }
+
+        /* If "method" (which is a list separated by ";") has more than one value,
+         * we keep the key so it will also be written as a passthrough key.
+         * That's required because Network Manager accepts multiple methods
+         * but Netplan accepts only one.
+         *
+         * TODO: eap_method needs to be fixed to store multiple methods.
+         */
+        if (split[1] == NULL || !g_strcmp0(split[1], ""))
+            _kf_clear_key(kf, "802-1x", "eap");
+
+        g_strfreev(split);
     }
 
     handle_generic_str(kf, "802-1x", "identity", &auth->identity);
@@ -493,10 +507,10 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
     nd = netplan_netdef_new(npp, nd_id, nd_type, NETPLAN_BACKEND_NM);
 
     /* Handle uuid & NM name/id */
-    nd->backend_settings.nm.uuid = g_strdup(uuid);
+    nd->backend_settings.uuid = g_strdup(uuid);
     _kf_clear_key(kf, "connection", "uuid");
-    nd->backend_settings.nm.name = g_key_file_get_string(kf, "connection", "id", NULL);
-    if (nd->backend_settings.nm.name)
+    nd->backend_settings.name = g_key_file_get_string(kf, "connection", "id", NULL);
+    if (nd->backend_settings.name)
         _kf_clear_key(kf, "connection", "id");
 
     if (nd_type == NETPLAN_DEF_TYPE_NM)
@@ -773,15 +787,15 @@ netplan_parser_load_keyfile(NetplanParser* npp, const char* filename, GError** e
 
         /* Last: handle passthrough for everything left in the keyfile
          *       Also, transfer backend_settings from netdef to AP */
-        ap->backend_settings.nm.uuid = g_strdup(nd->backend_settings.nm.uuid);
-        ap->backend_settings.nm.name = g_strdup(nd->backend_settings.nm.name);
+        ap->backend_settings.uuid = g_strdup(nd->backend_settings.uuid);
+        ap->backend_settings.name = g_strdup(nd->backend_settings.name);
         /* No need to clear nm.uuid & nm.name from def->backend_settings,
          * as we have only one AP. */
-        read_passthrough(kf, &ap->backend_settings.nm.passthrough);
+        read_passthrough(kf, &ap->backend_settings.passthrough);
     } else {
 only_passthrough:
         /* Last: handle passthrough for everything left in the keyfile */
-        read_passthrough(kf, &nd->backend_settings.nm.passthrough);
+        read_passthrough(kf, &nd->backend_settings.passthrough);
     }
 
     g_key_file_free(kf);
@@ -789,7 +803,7 @@ only_passthrough:
     /* validate definition-level conditions */
     if (!npp->missing_id)
         npp->missing_id = g_hash_table_new_full(g_str_hash, g_str_equal, NULL, g_free);
-    if (!validate_netdef_grammar(npp, nd, NULL, error))
+    if (!validate_netdef_grammar(npp, nd, error))
         return FALSE;
     return TRUE;
 }
