@@ -469,7 +469,7 @@ systemd_escape(char* string)
     gint exit_status = 0;
     gchar *escaped;
 
-    gchar *argv[] = {"bin" "/" "systemd-escape", string, NULL};
+    gchar *argv[] = {"bin" "/" "systemd-escape", "--", string, NULL};
     g_spawn_sync("/", argv, NULL, 0, NULL, NULL, &escaped, &stderrh, &exit_status, &err);
     #if GLIB_CHECK_VERSION (2, 70, 0)
     g_spawn_check_wait_status(exit_status, &err);
@@ -955,3 +955,39 @@ is_route_present(const NetplanNetDefinition* netdef, const NetplanIPRoute* route
 
     return FALSE;
 }
+/*
+ * Returns true if a policy rule already exists in the netdef rules list.
+ */
+gboolean
+is_route_rule_present(const NetplanNetDefinition* netdef, const NetplanIPRule* rule)
+{
+    const GArray* rules = netdef->ip_rules;
+
+    for (int i = 0; i < rules->len; i++) {
+        const NetplanIPRule* entry = g_array_index(rules, NetplanIPRule*, i);
+        if (
+                entry->family == rule->family &&
+                g_strcmp0(entry->from, rule->from) == 0 &&
+                g_strcmp0(entry->to, rule->to) == 0 &&
+                entry->table == rule->table &&
+                entry->priority == rule->priority &&
+                entry->fwmark == rule->fwmark &&
+                entry->tos == rule->tos
+           )
+            return TRUE;
+    }
+
+    return FALSE;
+}
+
+gboolean
+is_string_in_array(GArray* array, const char* value)
+{
+    for (unsigned i = 0; i < array->len; ++i) {
+        char* item = g_array_index(array, char*, i);
+        if (!g_strcmp0(value, item)) {
+            return TRUE;
+        }
+    }
+    return FALSE;
+}
