@@ -901,7 +901,7 @@ interface-name=bn0
 
 [bond]
 mode=802.3ad
-lacp_rate=10
+lacp_rate=fast
 miimon=10
 min_links=10
 xmit_hash_policy=none
@@ -938,7 +938,7 @@ method=ignore
         mii-monitor-interval: "10"
         up-delay: "10"
         down-delay: "10"
-        lacp-rate: "10"
+        lacp-rate: "fast"
         transmit-hash-policy: "none"
         ad-select: "none"
         arp-validate: "all"
@@ -1017,7 +1017,7 @@ method=auto
 address1=10.10.28.159/24
 address2=10.10.164.254/24
 address3=10.10.246.132/24
-dns=8.8.8.8;8.8.4.4;8.8.8.8;8.8.4.4;8.8.8.8;8.8.4.4;
+dns=8.8.8.8;8.8.4.4;
 
 [ipv6]
 method=auto
@@ -1035,10 +1035,6 @@ ip6-privacy=0
         addresses:
         - 8.8.8.8
         - 8.8.4.4
-        - 8.8.8.8
-        - 8.8.4.4
-        - 8.8.8.8
-        - 8.8.4.4
       dhcp4: true
       dhcp6: true
       apn: "internet"
@@ -1392,3 +1388,106 @@ method=auto
           ipv6.ip6-privacy: "-1"
           proxy._: ""
 '''.format(UUID)})
+
+    def test_multiple_eap_methods(self):
+        self.generate_from_keyfile('''[connection]
+id=MyWifi
+uuid={}
+type=wifi
+interface-name=wlp2s0
+
+[wifi]
+mode=infrastructure
+ssid=MyWifi
+
+[wifi-security]
+auth-alg=open
+key-mgmt=wpa-eap
+
+[802-1x]
+ca-cert=/path/to/my/crt.crt
+eap=peap;tls
+identity=username
+password=123456
+phase2-auth=mschapv2
+
+[ipv4]
+method=auto\n'''.format(UUID))
+        self.assert_netplan({UUID: '''network:
+  version: 2
+  wifis:
+    NM-{}:
+      renderer: NetworkManager
+      match:
+        name: "wlp2s0"
+      dhcp4: true
+      access-points:
+        "MyWifi":
+          auth:
+            key-management: "eap"
+            method: "peap"
+            identity: "username"
+            ca-certificate: "/path/to/my/crt.crt"
+            phase2-auth: "mschapv2"
+            password: "123456"
+          networkmanager:
+            uuid: "{}"
+            name: "MyWifi"
+            passthrough:
+              wifi-security.auth-alg: "open"
+              802-1x.eap: "peap;tls"
+      networkmanager:
+        uuid: "{}"
+        name: "MyWifi"
+'''.format(UUID, UUID, UUID)})
+
+    def test_single_eap_method(self):
+        self.generate_from_keyfile('''[connection]
+id=MyWifi
+uuid={}
+type=wifi
+interface-name=wlp2s0
+
+[wifi]
+mode=infrastructure
+ssid=MyWifi
+
+[wifi-security]
+auth-alg=open
+key-mgmt=wpa-eap
+
+[802-1x]
+ca-cert=/path/to/my/crt.crt
+eap=peap;
+identity=username
+password=123456
+phase2-auth=mschapv2
+
+[ipv4]
+method=auto\n'''.format(UUID))
+        self.assert_netplan({UUID: '''network:
+  version: 2
+  wifis:
+    NM-{}:
+      renderer: NetworkManager
+      match:
+        name: "wlp2s0"
+      dhcp4: true
+      access-points:
+        "MyWifi":
+          auth:
+            key-management: "eap"
+            method: "peap"
+            identity: "username"
+            ca-certificate: "/path/to/my/crt.crt"
+            phase2-auth: "mschapv2"
+            password: "123456"
+          networkmanager:
+            uuid: "{}"
+            name: "MyWifi"
+            passthrough:
+              wifi-security.auth-alg: "open"
+      networkmanager:
+        uuid: "{}"
+        name: "MyWifi"
+'''.format(UUID, UUID, UUID)})
